@@ -1,3 +1,4 @@
+from ..utils.validation import check_cu_co
 from sklearn.utils.validation import check_consistent_length
 from sklearn.utils.validation import check_array
 import numpy as np
@@ -61,8 +62,9 @@ def calc_costs(y_true, y_pred, cu, co):
     y_true, y_pred = _check_newsvendor_targets(y_true, y_pred)
     y_diff = y_pred - y_true
     func = np.vectorize(_multiply_cost_weights)
+    cu, co = check_cu_co(cu, co, y_true.shape[1])
     costs = func(y_diff, cu, co)
-    return costs
+    return -costs
 
 
 def calc_total_costs(y_true, y_pred, cu, co):
@@ -80,10 +82,7 @@ def calc_total_costs(y_true, y_pred, cu, co):
         -------
         total_costs : float
         """
-    y_true, y_pred = _check_newsvendor_targets(y_true, y_pred)
-    y_diff = y_pred - y_true
-    func = np.vectorize(_multiply_cost_weights)
-    costs = func(y_diff, cu, co)
+    costs = calc_costs(y_true, y_pred, cu, co)
     total_costs = np.sum(costs, axis=0)
     return total_costs
 
@@ -103,10 +102,6 @@ def calc_avg_costs(y_true, y_pred, cu, co):
         -------
         avg_costs : float
         """
-    y_true, y_pred = _check_newsvendor_targets(y_true, y_pred)
-    y_diff = y_pred - y_true
-    func = np.vectorize(_multiply_cost_weights)
-    costs = func(y_diff, cu, co)
-    total_costs = np.sum(costs, axis=0)
-    avg_costs = total_costs / costs.shape[0]
+    total_costs = calc_total_costs(y_true, y_pred, cu, co)
+    avg_costs = total_costs / y_true.shape[0]
     return avg_costs
